Module: StandardModel
- Extended by:
- ActiveSupport::Concern
- Defined in:
- lib/app/models/concerns/standard_model.rb
Overview
Mixin to standardize the setup of all models, i.e., the standard or base model definitions they should all have
Defined Under Namespace
Modules: ClassMethods
Class Method Summary collapse
Class Method Details
.included(base) ⇒ Object
10 11 12 13 14 15 16 17 18 19 |
# File 'lib/app/models/concerns/standard_model.rb', line 10 def self.included(base) base.class_eval do include Mongoid::Document include Mongoid::Timestamps # include App47Logger # include Auditable include Formable include AutoClearCache end end |